@@ -1,6 +1,6 @@
 package swat;
 
-our $VERSION = '0.1.67';
+our $VERSION = '0.1.68';
 
 use base 'Exporter'; 
 
@@ -1270,6 +1270,33 @@ Here are some examples:
     swat -q -s # run prove tests in random and quite mode
 
 
+=head1 Misc settings
+
+=over
+
+=item *
+
+swat_purge_cache
+
+=over
+
+=item *
+
+Set to `1', in case you need to clear swat cache directory, useful when swat tests get run periodically and a lot of cache files are created.
+
+
+=item *
+
+Default value is `0' ( do not clear cache ).
+
+
+=back
+
+
+
+=back
+
+
 =head1 Swat client
 
 Once swat is installed you get swat client at the `PATH':
